library("tidyverse")
library("xtable")

options("xtable.include.rownames" = FALSE,
        "xtable.booktabs" = TRUE,
        "xtable.type", "latex")

kotlin_dataclasses <- read_csv("data-csv/kotlin-dataclasses.csv",
                               col_names = c("type", "project", "file", "num_parents", "time_stamp", "commit", "count")) %>%
    select(-type)

kotlin_classes <- read_csv("data-csv/kotlin-classes.csv",
                           col_names = c("type", "project", "file", "is_open", "num_parents", "time_stamp", "commit", "count")) %>%
    select(-type)

kotlin_interfaces <- read_csv("data-csv/kotlin-interfaces.csv",
                              col_names = c("type", "project", "file", "num_parents", "time_stamp", "commit", "count")) %>%
    select(-type)

kotlin_dc_proj <- kotlin_dataclasses %>%
    group_by(project) %>%
    summarize(data_classes = sum(count))

kotlin_c_proj <- kotlin_classes %>%
    group_by(project) %>%
    summarize(classes = sum(count))

kotlin_i_proj <- kotlin_interfaces %>%
    group_by(project) %>%
    summarize(interfaces = sum(count))

full_join(kotlin_dc_proj, full_join(kotlin_c_proj, kotlin_i_proj)) %>%
    mutate(classes = recode(classes, .missing = 0),
           data_classes = recode(data_classes, .missing = 0),
           interfaces = recode(interfaces, .missing = 0)) %>%
    filter(classes > 0) %>%
    mutate(data_to_classes = data_classes/classes,
           interfaces_to_classes = interfaces/classes)
