#! usr/bin/env python3

#imports
import numpy as np
import pandas as pd
from scipy.stats import zscore
pd.options.mode.chained_assignment = None


def partition(data):
    '''
    Data: A dataframe guaranteed to have [project, file] columns
    Based on the number of files, we calculate zscore
    Large projects are those with zscore >=3
    Small project are below the median but below zscore=3
    Medium project are above the median but below zscore=3
    '''
    df = data[['project','file']].groupby('project', as_index = False).count()
    df_ = df.set_index('project').apply(zscore).reset_index()

    lrg = df_[df_['file']>=3] #large projects
    lrg['partition'] = 'large'

    rest= df[df.project.isin(df_[df_['file']<3].project)]
    sml = df[df['file']< np.median(rest['file'])] #small projects
    sml['partition'] = 'small'
    med = df[df['file'] >= np.median(rest['file'])] #medium project
    med['partition'] = 'medium'

    return pd.concat([sml[['project','partition']],med[['project','partition']], lrg[['project','partition']]])
