#!/usr/bin/env python3
# coding: utf-8


#imports
import time
import numpy as np
import pandas as pd
import os.path as osp
#from survival import *
from utils import *
from stats import *

# Set default plot style
sns.set(context='paper',
        style='whitegrid',
        palette='colorblind',
        font_scale=1.2)

#important functions
def plotting(d1, d2, labels, figure_name, xlabel=None, ylabel=None):
    plt.figure(figsize = (7,4))
    fig, ax = plt.subplots(1,1)
    sns.histplot(d1, kde = True, color = sns.color_palette()[0], bins = 100, ax = ax, legend = True, stat='percent')
    sns.histplot(d2, kde = True, color = sns.color_palette()[1], bins = 100, ax = ax, legend = True, stat='percent')
    upper_bound = np.max([np.quantile(d1,0.99), np.quantile(d2,0.99)])
    ax.set_xlim([0,upper_bound])
    if xlabel is not None:
        ax.set_xlabel(xlabel)
    if ylabel is not None:
        ax.set_ylabel(ylabel)
    # ax.yaxis.set_major_formatter(mticker.ScalarFormatter())
    plt.legend(labels)
    save_figure(fig,f"figures/{figure_name}.pdf", 5.25, 4)

def rq1():
    #load java and kotlin classes
    jv = load_classes('java')
    kt = load_classes('kotlin')

    # #load number of parents per class data
    # j_parent = load_num_parents('java')
    # k_parent = load_num_parents('kotlin')

    # #load number of child per class data
    # j_child = load_num_child('java')
    # k_child = load_num_child('kotlin')

    #extract distribution
    # d1j, d1k = num_classes_per_project(jv, kt)
    d2j, d2k = percent_open_per_project(jv, kt)
    # d2j['percent_open'] = d2j['percent_open'] * 100
    # d2k['percent_open'] = d2k['percent_open'] * 100
    # d3j, d3k = num_parents_per_class(j_parent, k_parent)
    # d4j, d4k = num_children_per_class(j_child, k_child)

    # plotting(d1j, d1k, ['Java', 'Kotlin'],'number-classes-java-vs-kotlin')
    plotting(d2j, d2k, ['Java', 'Kotlin'],'ratio-of-open-classes-java-vs-kotlin', xlabel = 'Percent Open Classes', ylabel = 'Percent of Projects')
    # plotting(d3j, d3k, ['Java', 'Kotlin'],'number-of-parents-java-vs-kotlin')
    # plotting(d4j, d4k, ['Java', 'Kotlin'],'number-of-children-java-vs-kotlin')

def rq2():
    #load kotin data
    kt = load_classes('kotlin')
    # k_parent = load_num_parents('kotlin')
    # k_child = load_num_child('kotlin')
    #split data into pure and mixed kotlin
    pure, mixed = split_kotlin(kt)
    # pure_parents, mixed_parents = split_kotlin(k_parent)
    # pure_child, mixed_child = split_kotlin(k_child)

    #extract distribution
    # d1j, d1k = num_classes_per_project(pure, mixed)
    d2j, d2k = percent_open_per_project(pure, mixed)
    # d3j, d3k = num_parents_per_class(pure_parents, mixed_parents)
    # d4j, d4k = num_children_per_class(pure_child, mixed_child)

    # plotting(d1k, d1j, ['Mixed Kotlin', 'Pure Kotlin'],'number-of-classes-pure-kotlin-vs-mixed-kotlin')
    plotting(d2k, d2j, ['Mixed Kotlin', 'Pure Kotlin'],'ratio-of-open-classes-pure-kotlin-vs-mixed-kotlin', xlabel = 'Percent Open Classes', ylabel = 'Percent of Projects')
    # plotting(d3k, d3j, ['Mixed Kotlin', 'Pure Kotlin'],'number-of-parents-pure-kotlin-vs-mixed-kotlin')
    # plotting(d4k, d4j, ['Mixed Kotlin', 'Pure Kotlin'],'number-of-children-pure-vs-mixed-kotlin')

def rq4():
    java   = load_class_churn_data('java')
    java = java[java['partition'] != 'large']
    kotlin = load_class_churn_data('kotlin')
    kotlin = kotlin[kotlin['partition'] != 'large']

    dist_jv_open   = list(java[java.isopen == True]['churn_rate'])
    dist_jv_closed = list(java[java.isopen == False]['churn_rate'])
    dist_kt_open   = list(kotlin[kotlin.isopen == True]['churn_rate'])
    dist_kt_closed = list(kotlin[kotlin.isopen == False]['churn_rate'])

    plotting(dist_jv_open, dist_jv_closed, ['Open Java', 'Closed Java'],'churn-rate-open-vs-closed-java')
    plotting(dist_kt_open, dist_kt_closed, ['Open Kotlin', 'Closed Kotlin'],'churn-rate-open-vs-closed-kotlin')


def rq5():
    #load data
    df_java, df_kotlin = load_with_tests('java'), load_with_tests('kotlin')
    df_java, df_kotlin = df_java[df_java.partition != 'large'], df_kotlin[df_kotlin.partition != 'large']

    #extract distributions
    dist_kt_test_open = list(df_kotlin[(df_kotlin.istest == True) & (df_kotlin.isopen == True)][['project','count']].groupby('project').sum()['count'])
    dist_kt_test_closed = list(df_kotlin[(df_kotlin.istest == True) & (df_kotlin.isopen == False)][['project','count']].groupby('project').sum()['count'])
    dist_jv_test_open = list(df_java[(df_java.istest == True) & (df_java.isopen == True)][['project','count']].groupby('project').sum()['count'])
    dist_jv_test_closed = list(df_java[(df_java.istest == True) & (df_java.isopen == False)][['project','count']].groupby('project').sum()['count'])

    #
    plotting(dist_kt_test_open, dist_kt_test_closed, ['Open Test Kotlin', 'Closed Test Kotlin'],'openness-of-test-classes-kotlin')
    plotting(dist_jv_test_open, dist_jv_test_closed, ['Open Test Java', 'Closed Test Java'],'openness-of-test-classes-java')

def plot_distributions():
    print("Plotting distribution for RQ1", flush=True)
    rq1()
    print("Plotting distribution for RQ2", flush=True)
    rq2()
    # print("Plotting distribution for RQ3", flush=True)
    # rq4()
    # print("Plotting distribution for RQ4", flush=True)
    # rq5()
if __name__ == "__main__":
    plot_distributions()
