library("tidyverse")
library("xtable")

options("xtable.include.rownames" = FALSE,
        "xtable.booktabs" = TRUE,
        "xtable.type", "latex")

kotlin_evolution <- read_csv("data-csv/evolution-kotlin.csv",
			     col_names = c("type", "project", "file", "class", "time", "commit", "is_open")) %>%
    select(-type)

classify_change_kind <- function(changes_list) {
    size <- length(changes_list)
    if (size == 1) {
        if (changes_list) {
	    "always_open"
	} else {
	    "always_closed"
	}
    } else if (size == 2) {
        first_el <- changes_list[1]
	if(first_el) {
	    "open_to_closed"
	} else {
	    "closed_to_open"
	}
    } else {
        "many_changes"
    }
}

kotlin_evolution %>%
filter(!is.na(is_open)) %>%
group_by(project, file, class) %>%
summarize(change_kind = classify_change_kind(is_open)) %>%
ungroup() %>%
mutate(change_kind = recode_factor(change_kind, `always_open` = "always_open", `always_closed` = "always_closed", `open_to_closed` = "open_to_closed", `closed_to_open` = "closed_to_open", `many_changes` = "many_changes")) %>%
group_by(project) %>% mutate(count = n()) %>% ungroup() %>% group_by(project, change_kind) %>% summarize(percent = n() / max(count)) %>%
ungroup() %>% group_by(change_kind) %>%
summarize(mean = mean(percent), sd = sd(percent)) %>%
xtable() %>% print(file = "tables/rq2-kotlin-summary.tex")