source("scripts/load-class-data.R")

kotlin_parents <- read_csv("data-csv/kotlin/parent-child.csv") %>%
    mutate(language = "Kotlin")

if (file.exists("data-csv/cached/kotlin-joined.csv")) {
    all_kotlin_joined <- read_csv("data-csv/cached/kotlin-joined.csv")
} else {
    all_kotlin_joined <- full_join(kotlin_classes, full_join(kotlin_interfaces, kotlin_dataclasses))
    write_csv(all_kotlin_joined, "data-csv/cached/kotlin-joined.csv")
}


if (file.exists("data-csv/cached/kotlin-with-parents.csv")) {
    kotlin_joined_with_parents <- read_csv("data-csv/cached/kotlin-with-parents.csv")
} else {
    kotlin_joined_with_parents <- full_join(all_kotlin_joined, kotlin_parents, by = c("project", "file")) %>%
        select(-language.y, -type.y, -isopen.y) %>%
        rename(type = type.x,
                      language = language.x)
   write_csv(kotlin_joined_with_parents, "data-csv/cached/kotlin-with-parents.csv") 
}

if(file.exists("data-csv/cached/kotlin-with-parent-lang.csv")) {
    with_parent_language <- read_csv("data-csv/cached/kotlin-with-parent-lang.csv")
} else {
    with_parent_language <- full_join(kotlin_joined_with_parents, kotlin_parents, by = c("parent" = "class", "project")) %>%
        select(-type.y, -language.y, -type.y, -parent.y) %>%
        rename(language = language.x,
                      type = type.x,
                      file = file.x,
       		      parent_file = file.y) %>%
        select(-isopen.x) %>%
        mutate(parent_language_is_java = (grepl("\\.java", parent_file) | grepl("java\\.", parent)),
	             parent_language_is_kotlin = grepl("\\.kt", parent_file),
		     parent_language_is_unknown = !(parent_language_is_java & parent_language_is_kotlin) & !is.na(parent)) %>%
        mutate(type = recode_factor(type,
                                    "class" = "Classes",
                                    "interface" = "Interfaces",
                                    "dataclass" = "Data Classes")) %>%
        filter(!is.na(class)) %>%
        group_by(type, project, file, class) %>%
        summarize(numparents = max(numparents),
	                   has_java_parent = any(parent_language_is_java),
			   has_kotlin_parent = any(parent_language_is_kotlin),
			   has_other_parent = any(parent_language_is_unknown),
			   isopen = any(isopen)) %>%
        ungroup() %>%
	mutate(parent_language = case_when(
	    has_java_parent & has_kotlin_parent & has_other_parent ~ "Java, Kotlin, UNK",
	    has_java_parent & has_kotlin_parent ~ "Java, Kotlin",
	    has_java_parent & has_other_parent ~ "Java, UNK",
	    has_java_parent ~ "Java",
	    has_kotlin_parent & has_other_parent ~ "Kotlin, UNK",
	    has_kotlin_parent ~ "Kotlin",
	    has_other_parent ~ "UNK",
	    TRUE ~ "NP"))
    write_csv(with_parent_language, "data-csv/cached/kotlin-with-parent-lang.csv")
}