#!/usr/bin/env python3

from utils import *

# Set default plot style
sns.set(context='paper',
        style='whitegrid',
        palette='colorblind',
        font_scale=1.2)

print("Summaries for RQ1")
data = load_class_interface_data()
df_fb = data.groupby(['language', 'type', 'project'], as_index = False)[['count']].sum().drop('project', axis=1)
df_fb['language'] = df_fb.apply(lambda x: 'Java' if x.language == 'java' else 'Kotlin', axis = 1)
df_fb['type'] = df_fb.apply(lambda x: 'Class' if x['type'] == 'class' else ('Interface' if x['type'] == 'interface' else 'Data Class'), axis = 1)
df_fb.rename(columns = {'language': 'Language'}, inplace = True)
save_table(df_fb.groupby(['Language', 'type']).describe().transpose(), 'tables/rq1-descriptive-types.tex')
ax = sns.boxplot(x='type', y='value', hue='Language', data=df_fb)
ax.set(xlabel='', ylabel='number per project')
save_figure(ax, "figures/rq1-types.png", 3, 3)

df_fb = data[data['type'] == 'class'].groupby(['language', 'isopen', 'project'], as_index = False)[['count']].sum().drop('project', axis = 1)
df_fb['language'] = df_fb.apply(lambda x: 'Java' if x.language == 'java' else 'Kotlin', axis = 1)
df_fb['isopen'] = df_fb.apply(lambda x: 'Open' if x.isopen else 'Closed', axis = 1)
df_fb.rename(columns = {'language': 'Language'}, inplace = True)
df_description = df_fb.groupby(['Language', 'isopen']).describe()
save_table(df_fb.groupby(['Language', 'isopen']).describe().transpose(), 'tables/rq1-descriptive-openness.tex')
df_description.columns = df_description.columns.droplevel(0)
df_description = df_description.reset_index()
df_description = df_description.melt(id_vars = ['Language', 'isopen'], value_vars=['min', '25%', '50%', '75%', 'max'])
ax = sns.boxplot(x='isopen', y='value', hue='Language', data=df_description)
ax.set(xlabel='', ylabel='number per project')
save_figure(ax, "figures/rq1-openness.png", 3, 3)

df_jnp = load_num_parents('java')
df_jnp['Language'] = 'Java'
df_knp = load_num_parents('kotlin')
df_knp['Language'] = 'Kotlin'
df_np = pd.concat([df_jnp, df_knp])
save_table(df_np.rename(columns = {'numparents': 'Num Parents'})[['Num Parents', 'Language']].groupby(['Language']).describe(), 'tables/rq1-num-parents.tex')

# print("Summaries for RQ3")
# df_jc = load_class_churn_data('java')
# df_jc['Language'] = 'Java'
# df_kt = load_class_churn_data('kotlin')
# df_kt['Language'] = 'Kotlin'
# df_churn = pd.concat([df_jc, df_kt]).rename(columns = {'churn_rate': 'Churn'})
# save_table(df_churn.groupby(['Language', 'isopen'])[['Churn']].describe().transpose(), 'tables/rq3-churn.tex', index_names = False, multicolumn_format = 'c', multirow = True, index = False)

print("Summaries for RQ5")
df_j = load_with_tests('java')
df_j['Language'] = 'Java'
df_k = load_with_tests('kotlin')
df_k['Language'] = 'Kotlin'
df_tests = pd.concat([df_j, df_k])
df_tests['isopen'] = df_tests['isopen'].apply(lambda x: 'Open' if x else 'Closed')
df_tests['istest'] = df_tests['istest'].apply(lambda x: 'Test' if x else 'Not Test')
save_table(df_tests.groupby(['Language', 'isopen', 'istest'])[['count']].describe().transpose(), 'tables/rq5-tests.tex')

print("Summaries for RQ2")
df_evolution = load_all_evolution_data()
df_evolution.rename(columns = {'language': 'Language', 'pattern': 'Change Pattern'}, inplace = True)
save_table(df_evolution.groupby(['Language', 'Change Pattern']).count()[['class']].rename(columns = {'class': 'Count'}), 'tables/rq2-descriptive.tex')
