#!/usr/bin/env python3

import sys

from graph_tool.all import *
from tqdm import tqdm

import csv

graphs = {}
ocd = {}

with open(sys.argv[1], "r") as fh:
    reader = csv.DictReader(fh)
    for row in reader:
        if row["project"] not in graphs.keys():
            graphs[row["project"]] = {}
        if row["project"] not in ocd.keys():
            ocd[row["project"]] = {}
        if row["class"] not in ocd[row["project"]]:
            ocd[row["project"]][row["class"]] = row["isopen"]
        if row["parent"] not in graphs[row["project"]]:
            graphs[row["project"]][row["parent"]] = []
        if row["class"] not in graphs[row["project"]][row["parent"]]:
            graphs[row["project"]][row["parent"]].append(row["class"])

with open(sys.argv[2], "w") as fh:
    writer = csv.DictWriter(fh, ["project", "isopen", "parents", "depth", "allchildren", "directchildren", "pathto"])
    writer.writeheader()
    for project, graph in tqdm(graphs.items()):
        g = Graph()
        is_open = g.new_vertex_property("string")
        name = g.new_vertex_property("string")
        color = g.new_vertex_property("int")
        paths = g.new_vertex_property("vector<string>")
        all_children = g.new_vertex_property("vector<int>")
        depth = g.new_vertex_property("int")
        graph_tmp = {}
        for parent, children in tqdm(graph.items()):
            if parent in graph_tmp.keys():
                parent_n = graph_tmp[parent]
            else:
                parent_n = g.add_vertex()
                graph_tmp[parent] = parent_n
                name[parent_n] = parent
                color[parent_n] = 0
                if parent in ocd[project].keys():
                    is_open[parent_n] = ocd[project][parent]
                else:
                    is_open[parent_n] = "UNK"
            for child in children:
                if child in graph_tmp.keys():
                    child_n = graph_tmp[child]
                else:
                    child_n = g.add_vertex()
                    graph_tmp[child] = child_n
                    name[child_n] = child
                    color[child_n] = 0
                    if child in ocd[project].keys():
                        is_open[child_n] = ocd[project][child]
                    else:
                        is_open[child_n] = "UNK"
                g.add_edge(parent_n, child_n)
        for vertex in g.vertices():
            if vertex.in_degree() != 0:
                continue
            work_stack = [vertex]
            name_stack = []
            while len(work_stack) != 0:
                work = work_stack.pop()
                if color[work] == 1:
                    color[work] == 2
                    depth[work] = max([depth[o] for o in work.out_neighbors()]) + 1
                    # Do Children
                    new_children = set()
                    for child in work.out_neighbors():
                        new_children.add(g.vertex_index[child])
                        for grands in all_children[child]:
                            new_children.add(grands)
                    all_children[work] = list(new_children)
                    writer.writerow({
                        "project": project,
                        "isopen": is_open[work],
                        "parents": len(list(work.in_neighbors())),
                        "depth": depth[work],
                        "allchildren": len(all_children[work]),
                        "directchildren": len(list(work.out_neighbors())),
                        "pathto": ' -> '.join(map(lambda item: name[item], work_stack)) + f" -> {name[work]}"
                    })
                    # name_stack.pop()
                elif color[work] == 2:
                    # name_stack.pop()
                    continue
                else:
                    if len(list(work.out_neighbors())) == 0:
                        color[work] = 2
                        depth[work] = 0
                        all_children[work] = []
                        name_stack.append(name[work])
                        writer.writerow({
                            "project": project,
                            "isopen": is_open[work],
                            "parents": len(list(work.in_neighbors())),
                            "depth": depth[work],
                            "allchildren": len(all_children[work]),
                            "directchildren": len(list(work.out_neighbors())),
                            "pathto": ' -> '.join(name_stack)
                        })
                        name_stack.pop()
                    else:
                        color[work] = 1
                        work_stack.append(work)
                        name_stack.append(name[work])
                        for o in work.out_neighbors():
                            work_stack.append(o)
