#!/usr/bin/env Rscript

options(echo = FALSE)

source("scripts/common.R")

kotlin_dit_noc <- read_csv("data-csv/kotlin/dit-noc-processed.csv") %>%
    mutate(language = "Kotlin")

java_dit_noc <- read_csv("data-csv/java/dit-noc-processed.csv") %>%
    mutate(language = "Java")

roots <- full_join(kotlin_dit_noc, java_dit_noc) %>%
    filter(parents == 0) %>%
    select(-isopen, -pathto, -parents) %>%
    pivot_longer(c(depth, allchildren, directchildren)) %>%
    ungroup() %>%
    mutate(name = recode_factor(name,
                                "depth" = "DIT",
                                "allchildren" = "NOC (Transitive)",
                                "directchildren" = "NOC (Direct)"))

roots %>%
    ggplot(aes(name, value, fill = language)) +
    geom_boxplot2(show.errorbar = TRUE, width.errorbar = 0.3)  +
    labs(fill = "Language") +
    xlab("") +
    ylab("Value") +
    our_theme
ggsave("figures/rq1-ditnoc.png", units = "in", width = 7, height = 3.5)

roots %>%
    group_by(language, name) %>%
    summarize(count = n(),
        mean = mean(value),
	std = sd(value),
	`25%` = quantile(value, probs = c(0.25)),
	`50%` = quantile(value, probs = c(0.5)),
	`75%` = quantile(value, probs = c(0.75)),
	max = max(value)) %>%
    xtable() %>% print(file = "tables/rq1-ditnoc.tex")