#!/usr/bin/env Rscript

options(echo = FALSE)

source("scripts/common.R")

source("scripts/load-class-data.R")

joined_table %>%
    group_by(language, type) %>%
    summarize(count = n(),
              mean = mean(numparents),
              std = sd(numparents),
              `25%` = quantile(numparents, probs = c(0.25)),
              `50%` = quantile(numparents, probs = c(0.5)),
              `75%` = quantile(numparents, probs = c(0.75)),
              max = max(numparents)) %>%
    xtable() %>% print(file = "tables/rq1-num-parents.tex")

joined_table %>%
    ggplot(aes(type, numparents, fill=language)) +
    geom_boxplot2(show.errorbar = TRUE, width.errorbar = 0.3) +
    scale_color_colorblind() +
    labs(fill = "Language") +
    ylab("Number of Parents") +
    xlab("") +
    our_theme
ggsave("figures/rq1-num-parents.png", units="in", width=7, height = 3.5)
