#!/usr/bin/env Rscript

options(echo = FALSE)

source("scripts/common.R")

source("scripts/load-class-data.R")

full_join(kotlin_classes, java_classes) %>%
    mutate(isopen = ifelse(isopen, "Open", "Not Open")) %>%
    mutate(isopen = ifelse(is.na(isopen), "Open", isopen)) %>%
    group_by(language, isopen, project) %>%
    summarize(n = sum(count)) %>%
    summarize(total = sum(n, na.rm = TRUE),
              mean = mean(n, na.rm = TRUE),
	      std = sd(n, na.rm = TRUE),
	      min = min(n, na.rm = TRUE),
	      `25%` = quantile(n, probs=c(0.25), na.rm = TRUE),
	      `50%` = quantile(n, probs=c(0.5), na.rm = TRUE),
	      `75%` = quantile(n, probs=c(0.75), na.rm = TRUE),
	      max = max(n, na.rm = TRUE)) %>%
    ungroup() %>%
    mutate(name = sprintf("%s (%s)", isopen, language)) %>%
    select(-language, -isopen) %>%
    transpose_tibble(col_names = "name", id_col = " ") %>%
    xtable() %>% print(file = "tables/rq1-openness.tex")
