#!/usr/bin/env Rscript

options(echo = FALSE)

source("scripts/common.R")

kotlin_class_evolution <- read_csv("data-csv/kotlin/evolution-classes.csv") %>%
    pivot_wider(names_from = type, values_from = count, values_fill = 0) %>%
    mutate(language = "Kotlin")

java_class_evolution <- read_csv("data-csv/java/evolution-classes.csv") %>%
    pivot_wider(names_from = type, values_from = count, values_fill = 0) %>%
    mutate(language = "Java")

combined <- full_join(kotlin_class_evolution, java_class_evolution) %>%
    mutate(start_closed = f,
	   start_open = nf,
           open_to_closed = tonf,
	   closed_to_open = tof)

combined %>%
    select(project, language, start_open, start_closed, open_to_closed, closed_to_open) %>%
    pivot_longer(cols = c(start_open, start_closed, open_to_closed, closed_to_open)) %>%
    group_by(language, name) %>%
    summarize(mean = mean(value),
              std = sd(value),
	      min = min(value),
	      `25%` = quantile(value, probs = c(0.25)),
      	      `50%` = quantile(value, probs = c(0.5)),
      	      `75%` = quantile(value, probs = c(0.75)),
	      max = max(value)) %>%
    mutate(name = recode_factor(name,
                                "number_changed" = "Number Changed",
                                "start_open" = "Start Open",
				"start_closed" = "Start Not Open",
                                "open_to_closed" = "Open -> Not Open",
				"closed_to_open" = "Not Open -> Open")) %>%
    rename(` ` = language, kind = name) %>%
    xtable() %>% print(file = "tables/rq2-classes-summary.tex")

combined %>%
    select(project, language, start_open, start_closed, open_to_closed, closed_to_open) %>%
    pivot_longer(cols = c(start_open, start_closed, open_to_closed, closed_to_open)) %>%
    mutate(name = recode_factor(name,
                                "number_changed" = "Number Changed",
                                "start_open" = "Start Open",
				"start_closed" = "Start Not Open",
                                "open_to_closed" = "Open -> Not Open",
				"closed_to_open" = "Not Open -> Open")) %>%
    ggplot() +
    geom_boxplot2(aes(name, value, fill=language), show.errorbar = TRUE, width.errorbar = 0.3) +
    scale_color_colorblind() +
    ylab("Number per Project") +
    xlab("") +
    our_theme
ggsave("figures/rq2-classes.png", units="in", width=7, height = 3.5)