options(echo = FALSE)

source("scripts/common.R")

kotlin_class_evolution <- read_csv("data-csv/kotlin/evolution-classes.csv") %>%
    pivot_wider(names_from = type, values_from = count, values_fill = 0) %>%
    mutate(kind = "Class")

kotlin_method_evolution <- read_csv("data-csv/kotlin/evolution-methods.csv") %>%
    pivot_wider(names_from = type, values_from = count, values_fill = 0) %>%
    mutate(kind = "Method")

kotlin_transitioned_projects <- read_csv("data-raw/kotlin/transitioned-classes.txt",
                                    col_names = c("type", "url", "class")) %>% select(-type)


kotlin_evolution_unified <- full_join(kotlin_class_evolution, kotlin_method_evolution)

kotlin_evolution_transitioned <- left_join(kotlin_transitioned_projects, kotlin_evolution_unified) %>%
    mutate(start_closed = f,
	   start_open = nf,
           open_to_closed = tonf,
	   closed_to_open = tof)

kotlin_evolution_transitioned %>%
    select(project, kind, start_open, start_closed, open_to_closed, closed_to_open) %>%
    pivot_longer(cols = c(start_open, start_closed, open_to_closed, closed_to_open)) %>%
    group_by(kind, name) %>%
    summarize(mean = mean(value),
              std = sd(value),
	      min = min(value),
	      `25%` = quantile(value, probs = c(0.25)),
      	      `50%` = quantile(value, probs = c(0.5)),
      	      `75%` = quantile(value, probs = c(0.75)),
	      max = max(value)) %>%
    mutate(name = recode_factor(name,
                                "number_changed" = "Number Changed",
                                "start_open" = "Start Open",
				"start_closed" = "Start Not Open",
                                "open_to_closed" = "Open -> Not Open",
				"closed_to_open" = "Not Open -> Open")) %>%
    rename(` ` = kind, kind = name) %>%
    xtable() %>% print(file="tables/rq2-transitioned-projects-evolution.tex")

#     mutate(total_start = f + nf) %>%
#     mutate(percent_changed = 100 * (u / total_start),
#            start_closed = 100 * (f / total_start),
# 	   start_open = 100 * (nf / total_start),
#            open_to_closed = ifelse(f == 0, 0, 100 * (tonf/f)),
# 	   closed_to_open = ifelse(nf == 0, 0, 100 * (tof/nf)))

# kotlin_evolution_transitioned %>%
#     select(project, kind, percent_changed, start_open, start_closed, open_to_closed, closed_to_open) %>%
#     pivot_longer(cols = c(percent_changed, start_open, start_closed, open_to_closed, closed_to_open)) %>%
#     group_by(kind, name) %>%
#     summarize(mean = mean(value, na.rm=TRUE),
#               std = sd(value, na.rm=TRUE),
# 	      min = min(value, na.rm=TRUE),
# 	      `25%` = quantile(value, probs = c(0.25), na.rm=TRUE),
#       	      `50%` = quantile(value, probs = c(0.5), na.rm=TRUE),
#       	      `75%` = quantile(value, probs = c(0.75), na.rm=TRUE),
# 	      max = max(value, na.rm=TRUE)) %>%
#     filter(!is.na(kind)) %>%
#     mutate(name = recode_factor(name,
#                                 "percent_changed" = "Percent Changed",
#                                 "start_open" = "Start Open",
# 				"start_closed" = "Start Closed",
#                                 "open_to_closed" = "Open -> Closed",
# 				"closed_to_open" = "Closed -> Open")) %>%
#     rename(` ` = kind, kind = name) %>%

kotlin_transitioned_projects %>%
    group_by(project) %>%
    summarize(num_transitioned = n()) %>%
    ungroup() %>%
    summarize(`Num. Projects` = n(),
              mean = mean(num_transitioned),
              std = sd(num_transitioned),
	      min = min(num_transitioned),
	      `25%` = quantile(num_transitioned, probs = c(0.25)),
	      `50%` = quantile(num_transitioned, probs = c(0.5)),
	      `75%` = quantile(num_transitioned, probs = c(0.75)),
	      max = max(num_transitioned)) %>%
    xtable() %>% print(file="tables/rq2-detected-transitions.tex")