options(echo = FALSE)

source("scripts/common.R")

commits <<- tibble()
churn_class <<- tibble()
churn_methods <<- tibble()
churn_filter <<- tibble()

read_data_files <- function(language) {
    commits <<- read_csv(sprintf("data-csv/%s/churn-commits.csv", language),
                col_names = c("type", "project", "count")) %>% select(-type)
    churn_class <<- read_csv(sprintf("data-csv/%s/churn-class.csv", language),
                col_names = c("type", "project", "is_open", "class", "churn")) %>% select(-type)
    churn_methods <<- read_csv(sprintf("data-csv/%s/churn-method.csv", language),
                col_names = c("type", "project", "is_open", "class", "method", "churn")) %>% select(-type)
    churn_filter <<- read_csv(sprintf("data-csv/%s/churn-filter.csv", language),
                col_names = c("type", "project", "class", "changes_count")) %>% select(-type)
}

read_data_files("kotlin")
commits_kotlin <- commits %>% mutate(Language = "Kotlin")
churn_class_kotlin <- churn_class %>% mutate(Language = "Kotlin")
churn_methods_kotlin <- churn_methods %>% mutate(Language = "Kotlin")
churn_filter_kotlin <- churn_filter

class_kotlin_filtered <- anti_join(left_join(churn_class_kotlin, commits_kotlin), churn_filter_kotlin)
method_kotlin_filtered <- anti_join(left_join(churn_methods_kotlin, commits_kotlin), churn_filter_kotlin)

read_data_files("java")
commits_java <- commits %>% mutate(Language = "Java")
churn_class_java <- churn_class %>% mutate(Language = "Java")
churn_methods_java <- churn_methods %>% mutate(Language = "Java")
churn_filter_java <- churn_filter

class_java_filtered <- anti_join(left_join(churn_class_java, commits_java), churn_filter_java)
method_java_filtered <- anti_join(left_join(churn_methods_java, commits_java), churn_filter_kotlin)

full_join(class_kotlin_filtered, class_java_filtered)  %>%
    filter(!is.na(churn)) %>%
    mutate(is_open = ifelse(is_open, "Open", "Not Open")) %>%
    group_by(Language, is_open) %>%
    summarize(mean = mean(churn),
              std = sd(churn),
	      min = min(churn),
	      `25%` = quantile(churn, probs = c(0.25)),
     	      `50%` = quantile(churn, probs = c(0.5)),
      	      `75%` = quantile(churn, probs = c(0.75)),
	      max = max(churn)) %>%
    ungroup() %>%
    mutate(name = sprintf("%s (%s)", is_open, Language)) %>%
    select(-Language) %>% select(-is_open) %>%
    transpose_tibble(col_names = name, id_col = " ") %>%
    select(` `, `Open (Java)`, `Not Open (Java)`, `Open (Kotlin)`, `Not Open (Kotlin)`) %>%
    xtable() %>% print(file = "tables/rq3-class-churn.tex")

full_join(method_kotlin_filtered, method_java_filtered)  %>%
    filter(!is.na(churn)) %>%
    mutate(is_open = ifelse(is_open, "Open", "Not Open")) %>%
    group_by(Language, is_open) %>%
    summarize(mean = mean(churn),
              std = sd(churn),
	      min = min(churn),
	      `25%` = quantile(churn, probs = c(0.25)),
     	      `50%` = quantile(churn, probs = c(0.5)),
      	      `75%` = quantile(churn, probs = c(0.75)),
	      max = max(churn)) %>%
    ungroup() %>%
    mutate(name = sprintf("%s (%s)", is_open, Language)) %>%
    select(-Language) %>% select(-is_open) %>%
    transpose_tibble(col_names = name, id_col = " ") %>%
    select(` `, `Open (Java)`, `Not Open (Java)`, `Open (Kotlin)`, `Not Open (Kotlin)`) %>%
    xtable() %>% print(file = "tables/rq3-method-churn.tex")