#!/usr/bin/env Rscript

options(echo = FALSE)

source("scripts/common.R")

source("scripts/load-parents-with-language.R")

with_parent_language %>%
    filter(!is.na(type)) %>%
    ggplot(aes(type, numparents, fill = parent_language)) +
    geom_boxplot2(show.errorbar = TRUE, width.errorbar = 0.3) +
    scale_color_colorblind() +
    labs(fill = "Parent Language") +
    ylab("Number of Parents") +
    xlab("") +
    our_theme
ggsave("figures/rq4-num-parents.png", units = "in", width = 7, height = 3.5)

with_parent_language %>%
    filter(!is.na(type)) %>%
    group_by(type, parent_language) %>%
    summarize(count = n(),
              mean = mean(numparents),
              std = sd(numparents),
              `25%` = quantile(numparents, probs = c(0.25)),
              `50%` = quantile(numparents, probs = c(0.5)),
              `75%` = quantile(numparents, probs = c(0.75)),
              max = max(numparents)) %>%
    ungroup() %>%
    rename(` ` = type,
                  `Parent Language` = parent_language) %>%
    xtable() %>% print(file = "tables/rq4-num-parents.tex")