#!/usr/bin/env Rscript

options(echo = FALSE)

source("scripts/common.R")

source("scripts/load-parents-with-language.R")

with_parent_language %>%
    filter(!is.na(type)) %>%
    group_by(parent_language, type, project) %>%
    summarize(count = n()) %>%
    ungroup() %>%
    ggplot(aes(type, count, fill = parent_language)) +
    geom_boxplot2(show.errorbar = TRUE, width.errorbar = 0.2) +
    scale_color_colorblind() +
    labs(fill = "Parent Language") +
    ylab("Number") +
    xlab("") +
    our_theme
ggsave("figures/rq4-summary.png", units = "in", width = 7, height = 3.5)

with_parent_language %>%
    filter(!is.na(type)) %>%
    group_by(parent_language, type, project) %>%
    summarize(count = n()) %>%
    summarize(total = sum(count),
              mean = mean(count),
	      std = sd(count),
	      min = min(count),
	      `25%` = quantile(count, probs = c(0.25)),
	      `50%` = quantile(count, probs = c(0.5)),
	      `75%` = quantile(count, probs = c(0.75)),
	      max = max(count)) %>%
    ungroup() %>%
    relocate(type, .before = parent_language) %>%
    arrange(type) %>%
    rename(` ` = type,
                  `Parent Language` = parent_language) %>%
    xtable() %>% print(file = "tables/rq4-summary.tex")