#!/usr/bin/env Rscript

options(echo = FALSE)

source("scripts/common.R")

source("scripts/load-tests-data.R")

re_joined_table %>%
    group_by(language, type, is_test) %>%
    summarize(count = n(),
              mean = mean(numparents),
              std = sd(numparents),
              `25%` = quantile(numparents, probs = c(0.25)),
              `50%` = quantile(numparents, probs = c(0.5)),
              `75%` = quantile(numparents, probs = c(0.75)),
              max = max(numparents)) %>%
    ungroup() %>%
    mutate(label = sprintf("%s (%s)", language, ifelse(is_test, "Test", "Not Test"))) %>%
    select(-language, -is_test) %>%
    relocate(label, .before = type) %>%
    arrange(label, type) %>%
    xtable() %>% print(file = "tables/rq5-num-parents.tex")

re_joined_table %>%
    mutate(language = recode_factor(sprintf("%s (%s)", language, ifelse(is_test, "Test", "Not Test")),
        "Java (Test)" = "Java (Test)",
	"Kotlin (Test)" = "Kotlin (Test)",
        "Java (Not Test)" = "Java (Not Test)",
	"Kotlin (Not Test)" = "Kotlin (Not Test)"),
	isopen = ifelse(isopen, "Open", "Not Open"),
	isopen = recode_factor(isopen, "Open" = "Open", "Not Open" = "Not Open")) %>%
    ggplot(aes(isopen, numparents, fill = language)) +
    geom_boxplot2(show.errorbar = TRUE, width.errorbar = 0.15) +
    scale_color_colorblind(breaks = c("Java (Test)", "Kotlin (Test)", "Java (Not Test)", "Kotlin (Not Test)")) +
    labs(fill = "Language") +
    ylab("Number of Parents") +
    xlab("") +
    our_theme
ggsave("figures/rq5-num-parents.png", units="in", width=7, height = 3.5)