#!/usr/bin/env Rscript

options(echo = FALSE)

source("scripts/common.R")

source("scripts/load-tests-data.R")

re_joined_table %>%
    filter(type == "Classes") %>%
    select(-type) %>%
    mutate(isopen = ifelse(isopen, "Open", "Not Open")) %>%
    mutate(isopen = ifelse(is.na(isopen), "Open", isopen)) %>%
    mutate(is_test = ifelse(is_test, "Test", "Not Test")) %>%
    group_by(language, isopen, is_test, project) %>%
    summarize(n = sum(count)) %>%
    summarize(total = sum(n),
               mean = mean(n),
	       std = sd(n),
	       min = min(n),
	       `25%` = quantile(n, probs = c(0.25)),
	       `50%` = quantile(n, probs = c(0.5)),
	       `75%` = quantile(n, probs = c(0.75)),
	       max = max(n)) %>%
    ungroup() %>%
    mutate(label = sprintf("%s (%s, %s)", language, isopen, is_test)) %>%
    select(-language, -isopen, -is_test) %>%
    relocate(label, .before = total) %>%
    arrange(label) %>%
    rename(` ` = label) %>%
    xtable() %>% print(file = "tables/rq5-openness.tex")