#!/usr/bin/env Rscript

options(echo = FALSE)

source("scripts/common.R")

source("scripts/load-tests-data.R")

only_tests %>%
    filter(type == "Classes") %>%
    mutate(isopen = ifelse(isopen, "Open", "Not Open")) %>%
    group_by(language, isopen, project) %>%
    summarize(count = sum(count)) %>%
    ungroup() %>%
    ggplot(aes(isopen, count, fill=language)) +
    geom_boxplot2(show.errorbar = TRUE, width.errorbar = 0.3) +
    scale_color_colorblind() +
    labs(fill = "Language") +
    ylab("Number per Project") +
    xlab("") +
    our_theme
ggsave("figures/rq5-tests.png", unit="in", width=7, height=7)

not_tests %>%
    filter(type == "Classes") %>%
    mutate(isopen = ifelse(isopen, "Open", "Not Open")) %>%
    group_by(language, isopen, project) %>%
    summarize(count = sum(count)) %>%
    ungroup() %>%
    ggplot(aes(isopen, count, fill=language)) +
    geom_boxplot2(show.errorbar = TRUE, width.errorbar = 0.3) +
    scale_color_colorblind() +
    labs(fill = "Language") +
    ylab("Number per Project") +
    xlab("") +
    our_theme
ggsave("figures/rq5-not-tests.png", unit="in", width=7, height=7)

re_joined_table %>%
    group_by(language, type, is_test, project) %>%
    summarize(count = sum(count)) %>%
    ungroup() %>%
    mutate(language = sprintf("%s (%s)", language, ifelse(is_test, "Test", "Not Test"))) %>%
    ggplot(aes(type, count, fill = language)) +
    geom_boxplot2(show.errorbar = TRUE, width.errorbar = 0.15) +
    scale_color_colorblind() +
    labs(fill = "Language") +
    our_theme
ggsave("figures/rq5-summary.png", units="in", width = 7, height = 3.5)

re_joined_table %>%
    group_by(language, type, is_test, project) %>%
    summarize(count = sum(count)) %>%
    summarize(total = sum(count),
              mean = mean(count),
	      std = sd(count),
	      min = min(count),
	      `25%` = quantile(count, probs = c(0.25)),
	      `50%` = quantile(count, probs = c(0.5)),
	      `75%` = quantile(count, probs = c(0.75)),
	      max = max(count)) %>%
    mutate(label = sprintf("%s (%s)", type, ifelse(is_test, "Test", "Not Test"))) %>%
    ungroup() %>%
    select(-type, -is_test) %>%
    relocate(label, .before = language) %>%
    arrange(label) %>%
    rename(` ` = label, `  ` = language) %>%
    xtable() %>% print(file = "tables/rq5-summary.tex")