#!/usr/bin/env python3


#imports
import pandas as pd
import numpy as np
import os.path as osp
from utils import save_figure, load_survival_data
import matplotlib.pyplot as plt
from sksurv.nonparametric import kaplan_meier_estimator
import seaborn as sns

sns.set(context='paper',
        style='whitegrid',
        palette='colorblind',
        font_scale=1.2)

def setup_data(open_to_close = True):
	java   = load_survival_data('java', openness = open_to_close)
	kotlin = load_survival_data('kotlin', openness = open_to_close)

	kotlin['language'] = 'Kotlin'
	java['language']   = 'Java'

	java = java[java.time < java.time.quantile(0.99)] #keeps removes 1% outliers

	# return pd.concat([java,kotlin])
	# open   = pd.concat([java[java['status'] == True], kotlin[kotlin['status'] == True]])
	# closed = pd.concat([java[java['status'] == False], kotlin[kotlin['status'] == False]])

	return pd.concat([java[['time','status','language']], kotlin[['time','status','language']]])

def fit_pm_model(data, label):
	languages = ['Java', 'Kotlin']
	fig = plt.figure()
	ax  = fig.add_subplot(1,1,1)
	for  lang in languages:
		filter = data['language'] == lang
		time_to_change, survival_prob = kaplan_meier_estimator(data['status'][filter], data['time'][filter])
		ax.step(time_to_change, survival_prob, where = 'post', label = lang)

	ax.set_ylabel("Est. probability of no-change $\hat{S}(t)$")
	ax.set_xlabel("time $t$ (days)")
	ax.set_xscale('log')
	ax.legend (loc = 'best')

	save_figure(fig,f"figures/{label}_survival_analysis.png", 5.25, 4)

def run_survival_analysis():
	open   = setup_data(open_to_close = True)
	closed = setup_data(open_to_close = False)
	fit_pm_model(open,'open_to_closed')
	fit_pm_model(closed,'closed_to_open')

if __name__ == '__main__':
        run_survival_analysis()
